<?php
/* 
This file is part of HeatMap Theme AdAptive
See license.txt (distributed with this file) for details of
license, contributors, copyright notices, credits and trademarks.
*/

/* DEFAULT THEME OPTIONS
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_get_default_theme_options' ) ):

	function heatmapthemead_get_default_theme_options() {
		
		$default_theme_options = array(
			'remove_welcome' => 'off',
			'remove_news' => 'off',
			'current_tab' => 'welcome_options',
			'color_scheme' => 'skywalking',
			'link_color'   => heatmapthemead_get_default_link_color( 'skywalking' ),
			'font_style' => 'opensans-arial',
			'theme_layout' => 'both-sidebars',
			'theme_home_page_layout' => 'both-sidebars',
			'theme_page_layout' => 'both-sidebars',
			'theme_post_layout' => 'both-sidebars',
			'max_width' => '1160',
			'minimum_theme_width' => '660',
			'maximum_theme_width' => '2000',
			'minimum_image_width' => '0',
			'maximum_image_width' => '2000',
			'default_image_width' => '615',
			'featured_page' => 'demo',
			'featured_page_title' => 'off',
			'facebook_url' => '',
			'twitter_url' => '',
			'googleplus_url' => '',
			'youtube_url' => '',
			'linkedin_url' => '',
			'myspace_url' => '',
			'rss_url' => '',
			'rss_comments_url' => '',
			'rss_icon' => 'on',
			'rss_comments_icon' => 'on',
			'credits_footer' => '<p>Powered by <a href="http://wordpress.org" target="_blank">WordPress</a> and <a href="' . HMTA_HEATMAPTHEME_COM_URL . '" target="_blank">HeatMap AdAptive Theme</a></p>',
			'reset_theme' => '',

			/* reserved place holders for pro options */
			'full_width_navigation' => 'off',
			'branding' => 'on',
			'primary_navigation' => 'on',
			'secondary_navigation' => 'on',
			'footer_navigation' => 'on',
			'post_navigation' => 'on',
			'meta_date' => 'on',
			'meta_author' => 'on',
			'meta_comments' => 'on',
			'meta_categories' => 'on',
			'meta_tags' => 'on',
			'page_meta' => 'on',
			'featured_image' => 'on',
			'featured_image_floatleft' => 'off',
			'facebook_like' => 'off',
			'twitter_like' => 'off',
			'googleplusone_like' => 'off',
			'css_scripts' => '',
			'head_scripts' => '',
			'footer_scripts' => '',
			'subfooter_navigation' => 'on'
			
		);
		return apply_filters( 'heatmapthemead_default_theme_options', $default_theme_options );
	}

endif; // heatmapthemead_get_default_theme_options


/* GET THEME OPTIONS
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_get_theme_options' ) ):

	function heatmapthemead_get_theme_options() {
		return get_option( 'heatmapthemead_theme_options', heatmapthemead_get_default_theme_options() );
	}

endif; // heatmapthemead_get_theme_options


/* CHANGE THE CAPABILITY REQUIRED TO SAVE OPTIONS
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_option_page_capability' ) ):

	function heatmapthemead_option_page_capability( $capability ) {
		return 'edit_theme_options';
	}

endif; // heatmapthemead_option_page_capability

add_filter( 'option_page_capability_heatmapthemead_options', 'heatmapthemead_option_page_capability' );


/* ADD OPTIONS PAGE TO ADMIN MENU
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_theme_options_add_page' ) ):

	function heatmapthemead_theme_options_add_page() {
		$theme_page = add_theme_page(
			__( 'HeatMap Options', 'heatmapthemead' ), // Name of page
			__( 'HeatMap Options', 'heatmapthemead' ), // Label in menu
			'edit_theme_options',                	// Capability required
			'theme_options',                     	// Menu slug, used to uniquely identify the page
			'heatmapthemead_theme_options_render_page' // Function that renders the options page
		);
	
		if ( ! $theme_page )
			return;
	}

endif; // heatmapthemead_theme_options_add_page

add_action( 'admin_menu', 'heatmapthemead_theme_options_add_page' );


/* REGISTER THEME OPTIONS
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_theme_options_init' ) ):

	function heatmapthemead_theme_options_init() {
	
		$options = heatmapthemead_get_theme_options();
	
		register_setting( 'heatmapthemead_options', 'heatmapthemead_theme_options', 'heatmapthemead_theme_options_validate' );
	
		// Only show the welcome page if the the remove welcome tick box has not been tickec
		if ( $options['remove_welcome'] != 'on' ):	
		
		/* WELCOME
		----------------------------------------------- */
		add_settings_section( 'welcome', '', 'heatmapthemead_settings_field_welcome_options_active', 'welcome_options' );	
			
			do_action('heatmapthemead_welcome_options_top_hook');
			
			// REMOVE WELCOME
			add_settings_field( 'remove_welcome', __( 'Make this Welcome tab disappear', 'heatmapthemead' ), 'heatmapthemead_settings_field_remove_welcome', 'welcome_options', 'welcome' );
			
			do_action('heatmapthemead_welcome_options_bottom_hook');
			
		endif;
		
		/* STYLE
		----------------------------------------------- */
		add_settings_section( 'style', '', 'heatmapthemead_settings_field_style_options_active', 'style_options' );
		
			do_action('heatmapthemead_style_options_top_hook');
			
			add_settings_field('custom_logo', __( 'Custom Logo', 'heatmapthemead' ), 'heatmapthemead_settings_field_custom_logo', 'style_options', 'style' );
			add_settings_field('color_scheme', __( 'Color Scheme', 'heatmapthemead' ), 'heatmapthemead_settings_field_color_scheme', 'style_options', 'style' );
			do_action('heatmapthemead_color_scheme_options_hook');
			
			add_settings_field('custom_background', __( 'Custom Background', 'heatmapthemead' ), 'heatmapthemead_settings_field_custom_background', 'style_options', 'style' );	
				
			add_settings_field( 'link_color', __( 'Link Color',     'heatmapthemead' ), 'heatmapthemead_settings_field_link_color', 'style_options', 'style' );
			add_settings_field( 'font_style', __( 'Font Style', 'heatmapthemead' ), 'heatmapthemead_settings_field_font_style', 'style_options', 'style' );		

			do_action('heatmapthemead_style_options_bottom_hook');

		/* LAYOUT
		----------------------------------------------- */
		add_settings_section( 'layout', '', 'heatmapthemead_settings_field_layout_options_active', 'layout_options' );	
		
			do_action('heatmapthemead_layout_options_top_hook');

			add_settings_field( 'layout', __( 'Default Layout', 'heatmapthemead' ), 'heatmapthemead_settings_field_layout', 'layout_options', 'layout' );
			
			do_action('heatmapthemead_layout_options_group_hook');
			
			add_settings_field( 'max_width', __( 'Maximum Theme Width', 'heatmapthemead' ), 'heatmapthemead_settings_field_max_width', 'layout_options', 'layout' );
			add_settings_field( 'default_image_width', __( 'Default Inserted Media Width', 'heatmapthemead' ), 'heatmapthemead_settings_field_default_image_width', 'layout_options', 'layout' );
			
			do_action('heatmapthemead_layout_options_bottom_hook');
	
		/* FEATURES
		----------------------------------------------- */
		add_settings_section( 'features', '', 'heatmapthemead_settings_field_features_options_active', 'features_options' );	
			
			do_action('heatmapthemead_features_options_top_hook');
			
			// FEATURED PAGE
			add_settings_section( 'homepage', 'Home Page', '__return_false', 'features_options' );
				add_settings_field( 'featured_page', __( 'Featured Page', 'heatmapthemead' ), 'heatmapthemead_settings_field_featured_page', 'features_options', 'homepage' );
				add_settings_field( 'featured_page_title', __( 'Featured Page Title', 'heatmapthemead' ), 'heatmapthemead_settings_field_featured_page_title', 'features_options', 'homepage' );
				
				do_action('heatmapthemead_featured_page_options_hook');
				
			do_action('heatmapthemead_features_options_bottom_hook');
			
		/* SOCIAL
		----------------------------------------------- */
		add_settings_section( 'social', __( '', 'heatmapthemead' ), 'heatmapthemead_settings_field_social_options_active', 'social_options' );
		
				do_action('heatmapthemead_social_options_top_hook');
		
				add_settings_field( 'facebook_url', __( 'Facebook Profile URL', 'heatmapthemead' ), 'heatmapthemead_settings_field_facebook_url', 'social_options', 'social' ); 
				add_settings_field( 'twitter_url', __( 'Twitter Profile URL', 'heatmapthemead' ), 'heatmapthemead_settings_field_twitter_url', 'social_options', 'social' ); 
				add_settings_field( 'googleplus_url', __( 'Google+ Profile URL', 'heatmapthemead' ), 'heatmapthemead_settings_field_googleplus_url', 'social_options', 'social' );
				add_settings_field( 'youtube_url', __( 'YouTube Profile URL', 'heatmapthemead' ), 'heatmapthemead_settings_field_youtube_url', 'social_options', 'social' );
				add_settings_field( 'linkedin_url', __( 'LinkedIn Profile URL', 'heatmapthemead' ), 'heatmapthemead_settings_field_linkedin_url', 'social_options', 'social' );
			
				add_settings_field( 'myspace_url', __( 'MySpace Profile URL', 'heatmapthemead' ), 'heatmapthemead_settings_field_myspace_url', 'social_options', 'social' );
				
				do_action('heatmapthemead_social_profile_options_hook');
	
			// RSS
			add_settings_section( 'rss', __( 'RSS', 'heatmapthemead' ), '__return_false', 'social_options' );
				add_settings_field( 'rss_icon', __( 'RSS Button', 'heatmapthemead' ), 'heatmapthemead_settings_field_rss_icon', 'social_options', 'rss' );
				add_settings_field( 'rss_comments_icon', __( 'RSS Comments Button', 'heatmapthemead' ), 'heatmapthemead_settings_field_rss_comments_icon', 'social_options', 'rss' );
				add_settings_field( 'rss_url', __( 'RSS URL', 'heatmapthemead' ), 'heatmapthemead_settings_field_rss_url', 'social_options', 'rss' );
				add_settings_field( 'rss_comments_url', __( 'RSS Comments URL', 'heatmapthemead' ), 'heatmapthemead_settings_field_rss_comments_url', 'social_options', 'rss' );
				
			do_action('heatmapthemead_social_options_bottom_hook');
						
		/* MISC
		----------------------------------------------- */
		add_settings_section( 'misc', '', 'heatmapthemead_settings_field_misc_options_active', 'misc_options' );
		
			do_action('heatmapthemead_misc_options_top_hook');	
			
			// INFO OPTIONS
			add_settings_section( 'info_options', __( 'Info Options', 'heatmapthemead' ), '__return_false', 'misc_options' );
					
				add_settings_field( 'remove_info', __( 'Hide HeatMap Theme News', 'heatmapthemead' ), 'heatmapthemead_settings_field_remove_news', 'misc_options', 'info_options' );	
					
				add_settings_field( 'remove_welcome', __( 'Hide the Welcome Tab', 'heatmapthemead' ), 'heatmapthemead_settings_field_remove_welcome', 'misc_options', 'info_options' );
		
		
			// RESET THEME TO DEFAULTS
			add_settings_section( 'reset', __( 'Reset', 'heatmapthemead' ), '__return_false', 'misc_options' );
				// REMOVE WELCOME
				add_settings_field( 'reset_theme', __( 'Reset Theme to Defaults', 'heatmapthemead' ), 'heatmapthemead_settings_field_reset_theme', 'misc_options', 'reset' );	
				
			do_action('heatmapthemead_misc_options_bottom_hook');												
	}

endif; // heatmapthemead_theme_options_init;

add_action( 'admin_init', 'heatmapthemead_theme_options_init' );



/* WELCOME TAB
--------------------------------------------------------------------------------------------- */

// Demo welcome tab content is included in heatmapthemead_settings_field_social_options_active()

/* REMOVE WELCOME
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_remove_welcome' ) ):

	function heatmapthemead_settings_field_remove_welcome() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-remove-welcome">
			<input type="checkbox" name="heatmapthemead_theme_options[remove_welcome]" id="heatmapthemead-remove-welcome" <?php checked( 'on', $options['remove_welcome'] ); ?> />
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_remove_welcome


/* STYLE TAB
--------------------------------------------------------------------------------------------- */

/* COLOUR SCHEMES
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_color_schemes' ) ):

	function heatmapthemead_color_schemes() {
		
		$color_scheme_options = array(
			'skywalking' => array(
				'value' => 'skywalking',
				'label' => __( 'Skywalking', 'heatmapthemead' ),
				'thumbnail' => get_template_directory_uri() . '/images/skywalking.png',
				'default_link_color' => '#1b8be0',
				'default_header_title_color' => '555555' /* important - no # required here */
			),
			'darthed' => array(
				'value' => 'darthed',
				'label' => __( 'Darthed', 'heatmapthemead' ),
				'thumbnail' => get_template_directory_uri() . '/images/darthed.png',
				'default_link_color' => '#e4741f',
				'default_header_title_color' => '9AA9EA' /* important - no # required here */
			),
		);
	
		return apply_filters( 'heatmapthemead_color_schemes', $color_scheme_options );
	}

endif; // heatmapthemead_color_schemes


/* COLOUR SCHEME THUMBNAIL SELECTOR
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_color_scheme' ) ):

	function heatmapthemead_settings_field_color_scheme() {
		
		$options = heatmapthemead_get_theme_options();
	
		foreach ( heatmapthemead_color_schemes() as $scheme ) {
		?>
		<div class="layout image-radio-option color-scheme">
			<label for="heatmapthemead-theme-options-color-scheme-<?php print $scheme['value']; ?>">
				<input type="radio" name="heatmapthemead_theme_options[color_scheme]" id="heatmapthemead-theme-options-color-scheme-<?php print $scheme['value']; ?>" value="<?php echo esc_attr( $scheme['value'] ); ?>" <?php checked( $options['color_scheme'], $scheme['value'] ); ?> />
			<span>
				<img src="<?php echo esc_url( $scheme['thumbnail'] ); ?>" width="136" height="122" alt="" />
				<?php echo $scheme['label']; ?>
			</span>
			</label>
			<input type="hidden" id="default-color-<?php echo esc_attr( $scheme['value'] ); ?>" value="<?php echo esc_attr( $scheme['default_link_color'] ); ?>" />
		</div>
		<?php
		}
		
		// move this into the pro plugin at some stage!
		
		if ( ! function_exists ( "heatmapthemeap_exists" ) ) {
		?>
			<div class="layout image-radio-option color-scheme">
				<label>
					<span>
					<?php
					print'<a href="' . HMTA_COLOUR_UPGRADE_URL . '" target="_blank"><img src="';
					print get_template_directory_uri();
					print '/images/more-colours.png" width="136" height="122" alt="" style="margin-top:2em;" /></a>';
					?>
					<a href="<?php print HMTA_COLOUR_UPGRADE_URL; ?>">Get More Colors</a>
					</span>
				</label>
			</div>
		<?php
		}
		else
		{
		?>
			<div class="layout image-radio-option color-scheme">
				<label>
					<span>
					<?php
					print'<a href="' . HMTA_PRO_COLOUR_UPGRADE_URL . '" target="_blank"><img src="';
					print get_template_directory_uri();
					print '/images/more-colours.png" width="136" height="122" alt="" style="margin-top:2em;" /></a>';
					?>
					<a href="<?php print HMTA_PRO_COLOUR_UPGRADE_URL; ?>">Get More Colors</a>
					</span>
				</label>
			</div>
		<?php	
		}
	}

endif; // heatmapthemead_settings_field_color_scheme


/* DEFAULT LINK COLOUR BASED ON SCHEME
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_get_default_link_color' ) ):

	function heatmapthemead_get_default_link_color( $color_scheme = null ) {
		if ( null === $color_scheme ) {
			$options = heatmapthemead_get_theme_options();
			$color_scheme = $options['color_scheme'];
		}
	
		$color_schemes = heatmapthemead_color_schemes();
		if ( ! isset( $color_schemes[ $color_scheme ] ) )
			return false;
	
		return $color_schemes[ $color_scheme ]['default_link_color'];
	}

endif; // heatmapthemead_get_default_link_color


/* LINK COLOUR
----------------------------------------------- */
// thanks Matt Wiebe for the the tute here
// http://make.wordpress.org/core/2012/11/30/new-color-picker-in-wp-3-5/

if ( ! function_exists( 'heatmapthemead_settings_field_link_color' ) ):

	function heatmapthemead_settings_field_link_color() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<input type="text" name="heatmapthemead_theme_options[link_color]" value="<?php echo esc_attr( $options['link_color'] ); ?>" class="heatmapthemead-link-colour" data-default-color="<?php print esc_attr ( heatmapthemead_get_default_link_color( $options['color_scheme'] ) ) ?>">
		<?php
	}

endif; // heatmapthemead_settings_field_link_color


/* SANITIZE LINK COLOUR
----------------------------------------------- */

function heatmapthemead_sanitize_hex_color( $color ) {
	if ( '' === $color )
		return '';

	// 3 or 6 hex digits, or the empty string.
	if ( preg_match('|^#([A-Fa-f0-9]{3}){1,2}$|', $color ) )
		return $color;

	return null;
}


/* CUSTOM LOGO
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_custom_logo' ) ):

	function heatmapthemead_settings_field_custom_logo() {
		printf(__('To add a logo','heatmapthemead'));
		print ' '; 
		printf(__('<a href="%s">use the Header options</a>', 'heatmapthemead'), admin_url('themes.php?page=custom-header')); 
	}

endif; // heatmapthemead_settings_field_link_color

/* CUSTOM BACKGROUND
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_custom_background' ) ):

	function heatmapthemead_settings_field_custom_background() {
		printf(__('To add a custom background','heatmapthemead')); 
		print ' '; 
		printf(__('<a href="%s">use the Background options</a>', 'heatmapthemead'), admin_url('themes.php?page=custom-background')); 
	}

endif; // heatmapthemead_settings_field_link_color



/* FONT STYLES
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_font_style' ) ):

	function heatmapthemead_font_style() {
		$select_options = array(
			'arial' => array(
				'value' =>	'arial',
				'label' => __( 'Arial', 'heatmapthemead' )
			),
			'verdana' => array(
				'value' =>	'verdana',
				'label' => __( 'Verdana', 'heatmapthemead' )
			),

			'opensans-arial' => array(
				'value' =>	'opensans-arial',
				'label' => __( 'Open Sans / Arial', 'heatmapthemead' )
			),
		);
	
		return apply_filters( 'heatmapthemead_font_style', $select_options );
	}

endif; // heatmapthemead_font_style


/* FONT STYLE OPTIONS
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_font_style' ) ):

	function heatmapthemead_settings_field_font_style() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="hmt-adapative-font-style">
			<select name="heatmapthemead_theme_options[font_style]" id="hmt-adapative-font-style">
				<?php
					$selected = $options['font_style'];
					$p = '';
					$r = '';
		
					foreach ( heatmapthemead_font_style() as $option ) {
						$label = $option['label'];
						if ( $selected == $option['value'] ) // Make default first in list
							$p = '<option style="padding-right: 10px;" ' . selected ( $selected, $option['value'] ) . ' value="' . esc_attr( $option['value'] ) . '">' . $label . '</option>';
						else
							$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr( $option['value'] ) . "'>$label</option>";
					}
					echo $p . $r;
				?>
			</select>
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_font_style


/* LAYOUT TAB
--------------------------------------------------------------------------------------------- */

/* HOME PAGE
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_home_page_layouts' ) ):

	function heatmapthemead_home_page_layouts( $layout_options ) {
		$layout_options = array(
			'both-sidebars' => array(
				'value' => 'both-sidebars',
				'label' => __( 'Both Sidebars', 'heatmapthemead' ),
				'thumbnail' => get_template_directory_uri() . '/images/both-sidebars.png',
			)
		);
	
		return apply_filters( 'heatmapthemead_home_page_layouts', $layout_options );
	}

endif; // heatmapthemead_home_page_layouts


/* PAGES
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_page_layouts' ) ):

	function heatmapthemead_page_layouts( $layout_options ) {
		$layout_options = array(
			'both-sidebars' => array(
				'value' => 'both-sidebars',
				'label' => __( 'Both Sidebars', 'heatmapthemead' ),
				'thumbnail' => get_template_directory_uri() . '/images/both-sidebars.png',
			)	
		);
	
		return apply_filters( 'heatmapthemead_page_layouts', $layout_options );
	}

endif; // heatmapthemead_page_layouts


/* POSTS
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_post_layouts' ) ):

	function heatmapthemead_post_layouts( $layout_options ) {
		$layout_options = array(
			'both-sidebars' => array(
				'value' => 'both-sidebars',
				'label' => __( 'Both Sidebars', 'heatmapthemead' ),
				'thumbnail' => get_template_directory_uri() . '/images/both-sidebars.png',
			)	
		);
	
		return apply_filters( 'heatmapthemead_post_layouts', $layout_options );
	}

endif; // heatmapthemead_post_layouts 


/* DEFAULT
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_layouts' ) ):

	function heatmapthemead_layouts( $layout_options ) {
		$layout_options = array(
			'both-sidebars' => array(
				'value' => 'both-sidebars',
				'label' => __( 'Both Sidebars', 'heatmapthemead' ),
				'thumbnail' => get_template_directory_uri() . '/images/both-sidebars.png',
			),	
			'primary-sidebar-content' => array(
				'value' => 'primary-sidebar-content',
				'label' => __( 'Primary Sidebar + Content', 'heatmapthemead' ),
				'thumbnail' => get_template_directory_uri() . '/images/primary-sidebar-content.png',
			),
			'content-secondary-sidebar' => array(
				'value' => 'content-secondary-sidebar',
				'label' => __( 'Content + Secondary Sidebar', 'heatmapthemead' ),
				'thumbnail' => get_template_directory_uri() . '/images/content-secondary-sidebar.png',
			),
			'content' => array(
				'value' => 'content',
				'label' => __( 'Content', 'heatmapthemead' ),
				'thumbnail' => get_template_directory_uri() . '/images/content.png',
			)	
		);
	
		return apply_filters( 'heatmapthemead_layouts', $layout_options );
	}

endif; // heatmapthemead_layouts


/* LAYOUT OPTIONS
----------------------------------------------- */

/* HOME PAGE LAYOUT SELECTOR
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_home_page_layout' ) ):

	function heatmapthemead_settings_field_home_page_layout() {
		
		$layout_options = '';
		
		$options = heatmapthemead_get_theme_options();
		foreach ( heatmapthemead_home_page_layouts( $layout_options ) as $layout ) {
			?>
			<div class="layout image-radio-option theme-layout">
			<label for="heatmapthemead-theme-home-page-layout-<?php print $layout['value']; ?>">
				<input type="radio" name="heatmapthemead_theme_options[theme_home_page_layout]" id="heatmapthemead-theme-home-page-layout-<?php print $layout['value']; ?>" value="<?php echo esc_attr( $layout['value'] ); ?>" <?php checked( $options['theme_home_page_layout'], $layout['value'] ); ?> />
				<span>
					<img src="<?php echo esc_url( $layout['thumbnail'] ); ?>" width="136" height="122" alt="" />
					<?php echo $layout['label']; ?>
				</span>
			</label>
			</div>
			<?php
		}
	}

endif; // heatmapthemead_settings_field_home_page_layout


/* PAGE LAYOUT SELECTOR
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_page_layout' ) ):

	function heatmapthemead_settings_field_page_layout() {
		
		$layout_options = '';
		
		$options = heatmapthemead_get_theme_options();
		foreach ( heatmapthemead_page_layouts( $layout_options ) as $layout ) {
			?>
			<div class="layout image-radio-option theme-layout">
			<label for="heatmapthemead-theme-page-layout-<?php print $layout['value']; ?>">
				<input type="radio" name="heatmapthemead_theme_options[theme_page_layout]" id="heatmapthemead-theme-page-layout-<?php print $layout['value']; ?>" value="<?php echo esc_attr( $layout['value'] ); ?>" <?php checked( $options['theme_page_layout'], $layout['value'] ); ?> />
				<span>
					<img src="<?php echo esc_url( $layout['thumbnail'] ); ?>" width="136" height="122" alt="" />
					<?php echo $layout['label']; ?>
				</span>
			</label>
			</div>
			<?php
		}
	}

endif; // heatmapthemead_settings_field_page_layout


/* POST LAYOUT SELECTOR
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_post_layout' ) ):

	function heatmapthemead_settings_field_post_layout() {
		
		$layout_options = '';
		
		$options = heatmapthemead_get_theme_options();
		foreach ( heatmapthemead_post_layouts( $layout_options ) as $layout ) {
			?>
			<div class="layout image-radio-option theme-layout">
			<label for="heatmapthemead-theme-post-layout-<?php print $layout['value']; ?>">
				<input type="radio" name="heatmapthemead_theme_options[theme_post_layout]" id="heatmapthemead-theme-post-layout-<?php print $layout['value']; ?>" value="<?php echo esc_attr( $layout['value'] ); ?>" <?php checked( $options['theme_post_layout'], $layout['value'] ); ?> />
				<span>
					<img src="<?php echo esc_url( $layout['thumbnail'] ); ?>" width="136" height="122" alt="" />
					<?php echo $layout['label']; ?>
				</span>
			</label>
			</div>
			<?php
		}
	}

endif; // heatmapthemead_settings_field_post_layout


/* DEFAULT LAYOUT SELECTOR
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_layout' ) ):

	function heatmapthemead_settings_field_layout() {
		
		$layout_options = '';
		
		$options = heatmapthemead_get_theme_options();
		foreach ( heatmapthemead_layouts( $layout_options ) as $layout ) {
			?>
			<div class="layout image-radio-option theme-layout">
			<label for="heatmapthemead-theme-layout-<?php print $layout['value']; ?>">
				<input type="radio" name="heatmapthemead_theme_options[theme_layout]" id="heatmapthemead-theme-layout-<?php print $layout['value']; ?>" value="<?php echo esc_attr( $layout['value'] ); ?>" <?php checked( $options['theme_layout'], $layout['value'] ); ?> />
				<span>
					<img src="<?php echo esc_url( $layout['thumbnail'] ); ?>" width="136" height="122" alt="" />
					<?php echo $layout['label']; ?>
				</span>
			</label>
			</div>
			<?php
		}
	}

endif; // heatmapthemead_settings_field_layout


/* MAX THEME WIDTH OPTIONS
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_max_width' ) ):

	function heatmapthemead_settings_field_max_width() {
		
		$options = heatmapthemead_get_theme_options();
		
		print '<label class="description" for="heatmapthemead-max-width">';
			print "<input id='heatmapthemead-max-width' class='regular-text heatmapthemead-regular-text' name='heatmapthemead_theme_options[max_width]' type='text' value='". $options['max_width'] . "' />";
			print ' ';
			_e ( 'Minimum recommended setting is', 'heatmapthemead' );
			print ' ';
			print absint ( $options['minimum_theme_width'] );
		print '</label>';
		
	}

endif; // heatmapthemead_settings_field_max_width


/* DEFAULT IMAGE WIDTH OPTIONS
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_default_image_width' ) ):

	function heatmapthemead_settings_field_default_image_width() {
		
		$options = heatmapthemead_get_theme_options();
		print '<label class="description" for="heatmapthemead-default-image-width">';
			print "<input id='heatmapthemead-default-image-width' class='regular-text heatmapthemead-regular-text' name='heatmapthemead_theme_options[default_image_width]' type='text' value='". absint ( $options['default_image_width'] ) . "' />";
			print ' ';
			_e ( 'Sets the default size for featured images and embedded media', 'heatmapthemead' );
		print '</label>';
		
	}

endif;


/* FEATURES TAB
--------------------------------------------------------------------------------------------- */

/* FEATURE PAGES SELECTION ARRAY
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_current_featured_pages' ) ):

	function heatmapthemead_current_featured_pages() {
		$select_options = array(
			'demo' => array(
				'value' =>	'demo',
				'label' => __( '- Demo Featured Page -', 'heatmapthemead' )
			),
			'off' => array(
				'value' =>	'off',
				'label' => __( '- Off -', 'heatmapthemead' )
			)
		);
		
		$allpages = get_pages();
		foreach( $allpages as $singlepage )
		{	
			$select_options [ $singlepage->ID ] ['value'] = $singlepage->ID;
			$select_options [ $singlepage->ID ] ['label'] = $singlepage->post_title;
		}
	
		return apply_filters( 'heatmapthemead_current_featured_pages', $select_options );
	}

endif; // heatmapthemead_current_featured_pages


/* FEATURED PAGE OPTIONS
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_featured_page' ) ):

	function heatmapthemead_settings_field_featured_page() {
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-max-width" >
			<select name="heatmapthemead_theme_options[featured_page]" id="heatmapthemead-max-width">
				<?php
					$selected = $options['featured_page'];
					$p = '';
					$r = '';
		
					foreach ( heatmapthemead_current_featured_pages() as $option ) {
						$label = $option['label'];
						if ( $selected == $option['value'] ) // Make default first in list
							$p = '<option style="padding-right: 10px;" ' . selected ( $selected, $option['value'] ) . ' value="' . esc_attr( $option['value'] ) . '">' . $label . '</option>';
						else
							$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr( $option['value'] ) . "'>$label</option>";
					}
					echo $p . $r;
				?>
			</select>
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_featured_page


/* FEATURED PAGE TITLE
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_featured_page_title' ) ):

	function heatmapthemead_settings_field_featured_page_title() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-featured-page-title">
			<input type="checkbox" name="heatmapthemead_theme_options[featured_page_title]" id="heatmapthemead-featured-page-title" <?php checked( 'on', $options['featured_page_title'] ); ?> />
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_featured_page_title


/* SOCIAL TAB
--------------------------------------------------------------------------------------------- */

/* TWITTER URL
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_twitter_url' ) ):

	function heatmapthemead_settings_field_twitter_url() {
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-twitter-url">
			<input type="text" name="heatmapthemead_theme_options[twitter_url]" id="heatmapthemead-twitter-url" value="<?php echo esc_url( $options['twitter_url'] ); ?>" />
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_twitter_url


/* FACEBOOK URL
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_facebook_url' ) ):

	function heatmapthemead_settings_field_facebook_url() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-facebook-url">
			<input type="text" name="heatmapthemead_theme_options[facebook_url]" id="heatmapthemead-facebook-url" value="<?php echo esc_url( $options['facebook_url'] ); ?>" />
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_facebook_url


/* GOOGLEPLUS URL
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_googleplus_url' ) ):

	function heatmapthemead_settings_field_googleplus_url() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-googleplus-url">
			<input type="text" name="heatmapthemead_theme_options[googleplus_url]" id="heatmapthemead-googleplus-url" value="<?php echo esc_url( $options['googleplus_url'] ); ?>" />
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_googleplus_url


/* YOUTUBE URL 
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_youtube_url' ) ):

	function heatmapthemead_settings_field_youtube_url() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-youtube-url">
			<input type="text" name="heatmapthemead_theme_options[youtube_url]" id="heatmapthemead-youtube-url" value="<?php echo esc_url( $options['youtube_url'] ); ?>" />
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_youtube_url


/* LINKEDIN URL
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_linkedin_url' ) ):

	function heatmapthemead_settings_field_linkedin_url() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-linkedin-url">
			<input type="text" name="heatmapthemead_theme_options[linkedin_url]" id="heatmapthemead-linkedin-url" value="<?php echo esc_url( $options['linkedin_url'] ); ?>" />
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_linkedin_url


/* MYSPACE URL
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_myspace_url' ) ):

	function heatmapthemead_settings_field_myspace_url() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-myspace-url">
			<input type="text" name="heatmapthemead_theme_options[myspace_url]" id="heatmapthemead-myspace-url" value="<?php echo esc_url( $options['myspace_url'] ); ?>" />
		</label>
		<?php
	}

endif;


/* RSS URL
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_rss_url' ) ):

	function heatmapthemead_settings_field_rss_url() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-rss-url">
			<input type="text" name="heatmapthemead_theme_options[rss_url]" id="heatmapthemead-rss-url" value="<?php echo esc_url( $options['rss_url'] ); ?>" />
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_rss_url


/* RSS COMMENT URL
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_rss_comments_url' ) ):

	function heatmapthemead_settings_field_rss_comments_url() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-rss-comments-url">
			<input type="text" name="heatmapthemead_theme_options[rss_comments_url]" id="heatmapthemead-rss-comments-url" value="<?php echo esc_url( $options['rss_comments_url'] ); ?>" />
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_rss_comments_url


/* RSS ICON
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_rss_icon' ) ):

	function heatmapthemead_settings_field_rss_icon() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-rss-icon">
			<input type="checkbox" name="heatmapthemead_theme_options[rss_icon]" id="heatmapthemead-rss-icon" <?php checked( 'on', $options['rss_icon'] ); ?> />
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_rss_icon


/* RSS COMMENTS ICON
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_rss_comments_icon' ) ):

	function heatmapthemead_settings_field_rss_comments_icon() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-rss-comments-icon">
			<input type="checkbox" name="heatmapthemead_theme_options[rss_comments_icon]" id="heatmapthemead-rss-comments-icon" <?php checked( 'on', $options['rss_comments_icon'] ); ?> />
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_rss_comments_icon

/* MISC TAB
--------------------------------------------------------------------------------------------- */

/* REMOVE NEWS
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_remove_news' ) ):

	function heatmapthemead_settings_field_remove_news() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-remove-news">
			<input type="checkbox" name="heatmapthemead_theme_options[remove_news]" id="heatmapthemead-remove-news" <?php checked( 'on', $options['remove_news'] ); ?> />
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_remove_news


/* RESET
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_settings_field_reset_theme' ) ):

	function heatmapthemead_settings_field_reset_theme() {
		$options = heatmapthemead_get_theme_options();
		?>
		<label for="heatmapthemead-reset-theme">
			<input type="checkbox" name="heatmapthemead_theme_options[reset_theme]" id="heatmapthemead-reset-theme" />
				<?php 
				_e( 'WARNING: If you tick this box and press SAVE all theme options will be reset back to their defaults', 'heatmapthemead' );  ?>
		</label>
		<?php
	}

endif; // heatmapthemead_settings_field_reset_theme


/* WELCOME TAB CONTENT
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_welcome_tab_content' ) ):

	function heatmapthemead_welcome_tab_content () {
	
		print '<div style="max-width: 600px">';
		print '<p>' . __('I am a responsive theme inspired by Google\'s ad placement recommendations. My widget positions are in all the right places, thoughtfully proportioned to fit industry standard ad sizes.', 'heatmapthemead') . '</p>'; 
		
		print '<p><strong>' . __('To add a logo','heatmapthemead') . '</strong> '; 
		printf(__('<a href="%s">use the Header options</a>.</p>', 'heatmapthemead'), admin_url('themes.php?page=custom-header')); 
		
		print '<p><strong>' . __('To create and position an ad','heatmapthemead') . '</strong> ';
		printf(__('<a href="%s">use the Widget Manager</a>', 'heatmapthemead'), admin_url('widgets.php'));
		print ' ';
	 	print __('and then drag a','heatmapthemead') . '<strong> ' . __('HeatMap AdAptive Ad widget', 'heatmapthemead') . '</strong> ' . __('into the widget position of your choice.', 'heatmapthemead') . '</p>';
		
		print '<h3>' . __('Here is a map of my widget positions', 'heatmapthemead') . '</h3>'; 
		
		print '<img src="';
		print get_template_directory_uri();
		print '/images/widget-placement-map.png"  alt="' . __( 'Widget Placement Map', 'heatmapthemead' ) . '" />';
		
		print '<hr/>';
		print '</div>';
	}

endif;

add_action ('heatmapthemead_settings_field_welcome_hook', 'heatmapthemead_welcome_tab_content');
do_action ('heatmapthemead_post_welcome_tab_content_hook');


/* RSS NEWS FEED
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_rss_feed' ) ):

	function heatmapthemead_rss_feed () {

	$options = heatmapthemead_get_theme_options();
	
	if ( $options['remove_news'] == 'on' ) return;
		
		// Get RSS Feed(s)
		include_once( ABSPATH . WPINC . '/feed.php' );
		
		// Get a SimplePie feed object from the specified feed source.
		$rss = fetch_feed( HMTA_HEATMAPTHEME_COM_URL . '/feed/' );
		
		if ( ! is_wp_error( $rss ) ) : // Checks that the object is created correctly
		
			// Figure out how many total items there are, but limit it to 5. 
			$maxitems = $rss->get_item_quantity( 5 ); 
		
			// Build an array of all the items, starting with element 0 (first element).
			$rss_items = $rss->get_items( 0, $maxitems );
		
			print '<div id="heatmapthemead-rss-feed">';
			print '<h3>' . __('HeatMap Theme News', 'heatmapthemead') . '</h3>';
			
			?>	
			<ul>
				<?php if ( $maxitems == 0 ) : ?>
					<li><?php _e( 'No items', 'heatmapthemead' ); ?></li>
				<?php else : ?>
					<?php // Loop through each feed item and display each item as a hyperlink. ?>
					<?php foreach ( $rss_items as $item ) : ?>
						<li>
							<?php echo '<span class="heatmapthemead-rss-date">' . esc_html( $item->get_date('M jS, Y') ) . '</span><br/>'; ?>
							<blockquote>
							<span class="heatmapthemead-rss-title">
								<a href="<?php echo esc_url( $item->get_permalink() ); ?>"
								title="<?php printf( __( 'Posted %s', 'heatmapthemead' ), $item->get_date('j F Y | g:i a') ); ?>">
								<?php echo esc_html( $item->get_title() ); ?>				
								</a>
							</span>	
							</blockquote>
						</li>
					<?php endforeach; ?>
				<?php endif; ?>
			</ul>
			<?php	
		
			print '</div>';
				
		endif;
		
	}

endif; // heatmapthemead_rss_feed


/* VALID TABS
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_valid_tabs' ) ):

	function heatmapthemead_valid_tabs() {
		
		$valid_tab_options = array(	'welcome_options' => 'Welcome', 
									'style_options' => 'Style', 
									'layout_options' => 'Layout', 
									'features_options' => 'Features', 
									'social_options' => 'Social', 
									'misc_options' => 'Misc' 
							);
	
		return apply_filters( 'heatmapthemead_valid_tabs', $valid_tab_options );
	}

endif; // heatmapthemead_valid_tabs


/* HIDDEN FIELDS USED TO DETERMINE WHICH TAB IS CURRENTLY ACTIVE
--------------------------------------------------------------------------------------------- */

function heatmapthemead_settings_field_social_options_active () { ?>
	<input type="hidden" name="heatmapthemead_theme_options[social_options_active]" id="social-options-active" value="yes"/><?php
	heatmapthemead_rss_feed();
	do_action('heatmapthemead_settings_field_social_hook');
}
function heatmapthemead_settings_field_welcome_options_active () { ?>
	<input type="hidden" name="heatmapthemead_theme_options[welcome_options_active]" id="welcome-options-active" value="yes"/>
	<?php
	heatmapthemead_rss_feed();
	do_action('heatmapthemead_settings_field_welcome_hook');
}
function heatmapthemead_settings_field_layout_options_active () { ?>
<input type="hidden" name="heatmapthemead_theme_options[layout_options_active]" id="layout-options-active" value="yes"/><?php
	heatmapthemead_rss_feed();
	do_action('heatmapthemead_settings_field_layout_hook');
}
function heatmapthemead_settings_field_features_options_active () { ?>
	<input type="hidden" name="heatmapthemead_theme_options[features_options_active]" id="features-options-active" value="yes"/><?php
	heatmapthemead_rss_feed();
	do_action('heatmapthemead_settings_field_features_hook');
}
function heatmapthemead_settings_field_style_options_active () {?>
	<input type="hidden" name="heatmapthemead_theme_options[style_options_active]" id="colour-options-active" value="yes"/><?php
	heatmapthemead_rss_feed();
	do_action('heatmapthemead_settings_field_style_hook');
}
function heatmapthemead_settings_field_misc_options_active () { ?>
	<input type="hidden" name="heatmapthemead_theme_options[misc_options_active]" id="misc-options-active" value="yes"/><?php
	heatmapthemead_rss_feed();
	do_action('heatmapthemead_settings_field_misc_hook');
}


/* RENDER THE OPTIONS PAGE DEPENDANT ON ACTIVE TAB
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_theme_options_render_page' ) ):

	function heatmapthemead_theme_options_render_page() {
		
		$options = heatmapthemead_get_theme_options();
		?>
		<div class="wrap">
			<?php
			print'<img src="';
			print get_template_directory_uri();
			print '/images/mobile-icon.png" width="34" height="34" alt="" style="float:left; margin: 7px 8px 0 0;" />';
			
			// if the pro version exists show different buttons
			// move this out into the pro plugin itself at some stage!!
			
			if ( ! function_exists ( "heatmapthemeap_exists" ) ) {
			?>
				<span id="heatmapthemead-theme-options-buttons">
					<span class="button-primary"><a href="<?php print HMTA_USER_GUIDE_URL; ?>"><?php _e( 'User Guide' , 'heatmapthemead' ) ?></a></span> 
					<span class="button-primary"><a href="<?php print HMTA_SUPPORT_URL; ?>"><?php _e( 'Support', 'heatmapthemead' ) ?></a></span>
				</span>   
			<?php 
			}
			else
			{ ?>
				<span id="heatmapthemead-theme-options-buttons">
					<span class="button-primary"><a href="<?php print HMTA_PRO_USER_GUIDE_URL; ?>"><?php _e( 'User Guide' , 'heatmapthemead' ) ?></a></span> 
					<span class="button-primary"><a href="<?php print HMTA_PRO_SUPPORT_URL; ?>"><?php _e( 'Support', 'heatmapthemead' ) ?></a></span>
				</span> 
			<?php	
			}
			
			$theme_name = wp_get_theme(); ?>
			<h2><?php printf( __( '%s Options', 'heatmapthemead' ), $theme_name ); ?></h2>
			
			<?php settings_errors(); ?>
	
			<form method="post" action="options.php">
			
				<?php 
				$active_tab = isset( $_GET[ 'tab' ] ) ? $_GET[ 'tab' ] : $options['current_tab'];
				
				// if the welcome tab is set not to appear and the current tab is set to welcome_options then show style options instead
				if ( ( $active_tab == 'welcome_options' ) && ( $options ['remove_welcome'] == 'on' ) )
					$active_tab = 'style_options';				
				?>
				<input type="hidden" name="current_tab" value="<?php print $active_tab; ?>">
				
				<?php
				// display the theme options page icon
				print '<a href="' . HMTA_HEATMAPTHEME_COM_URL . '" target="_blank">';
				print'<img src="';
				print get_template_directory_uri();
				print '/images/heatmap-icon.png" width="193" height="32" alt="" style="float:right; margin: 4px 0 0 0;" />'; 
				print '</a>';
				
				// show the options page tabs
				?>      
				<h2 class="nav-tab-wrapper"> 
				 
					<?php
					if ($options['remove_welcome'] != 'on' ):
					?>
						<a href="?page=theme_options&tab=welcome_options" class="nav-tab <?php echo $active_tab == 'welcome_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Welcome', 'heatmapthemead' ) ?></a> 
					<?php
					endif;
					?>
					<a href="?page=theme_options&tab=style_options" class="nav-tab <?php echo $active_tab == 'style_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Style', 'heatmapthemead' ) ?></a> 
					<a href="?page=theme_options&tab=layout_options" class="nav-tab <?php echo $active_tab == 'layout_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Layout', 'heatmapthemead' ) ?></a> 
					<a href="?page=theme_options&tab=features_options" class="nav-tab <?php echo $active_tab == 'features_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Features', 'heatmapthemead' ) ?></a>  
					<a href="?page=theme_options&tab=social_options" class="nav-tab <?php echo $active_tab == 'social_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Social', 'heatmapthemead' ) ?></a>  
					<a href="?page=theme_options&tab=misc_options" class="nav-tab <?php echo $active_tab == 'misc_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Misc', 'heatmapthemead' ) ?></a> 
				</h2>
				<?php
				settings_fields( 'heatmapthemead_options' );
	
				if ( $active_tab == 'welcome_options' ) {
					do_settings_sections( 'welcome_options' );
				}
				if ( $active_tab == 'style_options' ) {
					do_settings_sections( 'style_options' );
				}
				if ( $active_tab == 'layout_options' ) {
					do_settings_sections( 'layout_options' );
				}
				if ( $active_tab == 'features_options' ) {
					do_settings_sections( 'features_options' );
				}
				if ( $active_tab == 'social_options' ) {
					do_settings_sections( 'social_options' );
				}
				if ( $active_tab == 'misc_options' ) {
					do_settings_sections( 'misc_options' );
				}				
				submit_button();
				?>
			</form>
		</div>
		<?php
	}

endif; // heatmapthemead_theme_options_render_page


/* SANITIZE
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_theme_options_validate' ) ):

	function heatmapthemead_theme_options_validate( $input ) {
		$defaults = heatmapthemead_get_default_theme_options();
		$output = heatmapthemead_get_theme_options();
		global $wp_customize;
		
			// If we are in the customize screen ($wp_customize is set) then validate in this way!
			// Remember that we also validate for the individual tabs too
			// and yes I am repeating myself, but hey I find it clearer to understand this way
			if ( isset( $wp_customize ) ) {
				// COLOURS
				if ( isset( $input['color_scheme'] ) && array_key_exists( $input['color_scheme'], heatmapthemead_color_schemes() ) )
					$output['color_scheme'] = $input['color_scheme'];
				// LINK COLOUR
				$output['link_color'] = $defaults['link_color'] = heatmapthemead_get_default_link_color( $output['color_scheme'] );
				if ( isset( $input['link_color'] ) && preg_match( '/^#?([a-f0-9]{3}){1,2}$/i', $input['link_color'] ) )
					$output['link_color'] = '#' . strtolower( ltrim( $input['link_color'], '#' ) );
				// LAYOUT
				if ( isset( $input['theme_layout'] ) && array_key_exists( $input['theme_layout'], heatmapthemead_layouts( $layout_options ) ) )
					$output['theme_layout'] = $input['theme_layout'];
					
				$output = apply_filters ('heatmapthemead_customize_options_sanitize_hook', $output, $input );			
			}
		
			// validating tabs when they are saved
			
			// WELCOME
			if ( isset ($input['welcome_options_active'])):
			
				// REMOVE WELCOME
				if ( ! isset( $input['remove_welcome'] ) )
					$input['remove_welcome'] = 'off';
				$output['remove_welcome'] = ( $input['remove_welcome'] == 'on' ? 'on' : 'off' );
				
				$output = apply_filters ('heatmapthemead_welcome_options_sanitize_hook', $output, $input );
				
			endif;
	
			// FEATURES
			if ( isset ($input['features_options_active'])):
			
				// FEATURED PAGE
				if ( isset( $input['featured_page'] ) && array_key_exists( $input['featured_page'], heatmapthemead_current_featured_pages() ) )
					$output['featured_page'] = $input['featured_page'];		
				// FEATURED PAGE TITLE
				if ( ! isset( $input['featured_page_title'] ) )
					$input['featured_page_title'] = 'off';
				$output['featured_page_title'] = ( $input['featured_page_title'] == 'on' ? 'on' : 'off' );	
				
				$output = apply_filters ('heatmapthemead_features_options_sanitize_hook', $output, $input );
										
			endif;
			
			$layout_options = '';
			
			if ( isset ($input['layout_options_active'])):
				// THEME LAYOUT
				if ( isset( $input['theme_layout'] ) && array_key_exists( $input['theme_layout'], heatmapthemead_layouts( $layout_options ) ) )
					$output['theme_layout'] = $input['theme_layout'];			
				// MAX WIDTH
				$check_int = (int)$input['max_width'] ;
				if ( ( is_numeric ( $input['max_width'] ) ) && ( ( $check_int >= $defaults['minimum_theme_width'] ) && ($check_int < $defaults['maximum_theme_width'] ) ) )	
					$output['max_width'] = $input['max_width'];
				// DEFAULT IMAGE WIDTH
				$check_int = (int)$input['default_image_width'];
				if ( ( is_numeric ( $input['default_image_width'] ) ) && ( ( $check_int > $defaults['minimum_image_width'] ) && ($check_int < $defaults['maximum_image_width'] ) ) )	
					$output['default_image_width'] = $input['default_image_width'];	
					
				$output = apply_filters ('heatmapthemead_layout_options_sanitize_hook', $output, $input );
					
			endif;	
				
			// STYLE
			if ( isset ($input['style_options_active'])):
				// COLOUR SCHEME
				if ( isset( $input['color_scheme'] ) && array_key_exists( $input['color_scheme'], heatmapthemead_color_schemes() ) )
					$output['color_scheme'] = $input['color_scheme'];
				// LINK COLOUR
				$output['link_color'] = $defaults['link_color'] = heatmapthemead_get_default_link_color( $output['color_scheme'] );
				if ( isset( $input['link_color'] ) && preg_match( '/^#?([a-f0-9]{3}){1,2}$/i', $input['link_color'] ) )
					$output['link_color'] = '#' . strtolower( ltrim( $input['link_color'], '#' ) );
				// FONT STYLE
				if ( array_key_exists( $input['font_style'], heatmapthemead_font_style() ) )
					$output['font_style'] = $input['font_style'];
					
				$output = apply_filters ('heatmapthemead_style_options_sanitize_hook', $output, $input );
					
			endif;
	
			// SOCIAL
			if ( isset ($input['social_options_active'])):
				// FACEBOOK URL	
				if ( isset( $input['facebook_url'] ) )
					$output['facebook_url'] = esc_url_raw ( $input['facebook_url'] );
				// TWITTER URL
				if ( isset( $input['twitter_url'] ) )
					$output['twitter_url'] = esc_url_raw ( $input['twitter_url'] );
				// GOOGLEPLUS URL
				if ( isset( $input['googleplus_url'] ) )
					$output['googleplus_url'] = esc_url_raw ( $input['googleplus_url'] );
				// YOUTUBE URL
				if ( isset( $input['youtube_url'] ) )
					$output['youtube_url'] = esc_url_raw ( $input['youtube_url'] );
				// LINKEDIN URL
				if ( isset( $input['linkedin_url'] ) )
					$output['linkedin_url'] = esc_url_raw ( $input['linkedin_url'] );
				// MYSPACE URL
				if ( isset( $input['myspace_url'] ) )
					$output['myspace_url'] = esc_url_raw ( $input['myspace_url'] );
				// RSS URL
				if ( isset( $input['rss_url'] ) )
					$output['rss_url'] = esc_url_raw ( $input['rss_url'] );	
				// RSS COMMENTS URL
				if ( isset( $input['rss_comments_url'] ) )
					$output['rss_comments_url'] = esc_url_raw ( $input['rss_comments_url'] );
				// RSS ICON
				if ( ! isset( $input['rss_icon'] ) )
					$input['rss_icon'] = 'off';
				$output['rss_icon'] = ( $input['rss_icon'] == 'on' ? 'on' : 'off' );
				// RSS COMMENTS ICON
				if ( ! isset( $input['rss_comments_icon'] ) )
					$input['rss_comments_icon'] = 'off';
				$output['rss_comments_icon'] = ( $input['rss_comments_icon'] == 'on' ? 'on' : 'off' );
			
				$output = apply_filters ('heatmapthemead_social_options_sanitize_hook', $output, $input );	
				
			endif;
			
			// MISC
			if ( isset ($input['misc_options_active'])):

				// DISPLAY WELCOME
				if ( ! isset( $input['remove_welcome'] ) )
					$input['remove_welcome'] = 'off';
				$output['remove_welcome'] = ( $input['remove_welcome'] == 'on' ? 'on' : 'off' );
				// DISPLAY NEWS
				if ( ! isset( $input['remove_news'] ) )
					$input['remove_news'] = 'off';
				$output['remove_news'] = ( $input['remove_news'] == 'on' ? 'on' : 'off' );
					
				$output = apply_filters ('heatmapthemead_misc_options_sanitize_hook', $output, $input );	
					
			endif;	
			
			// RESET THEME OPTIONS
			if ( isset( $input['reset_theme'] ) )
				if ( $input['reset_theme'] == 'on' ) $output = $defaults;
	
			// VALIDATE TABS
			if ( isset ( $_POST[ 'current_tab' ] ) ) $active_tab = $_POST[ 'current_tab' ];
			if ( isset( $active_tab ) && array_key_exists( $active_tab, heatmapthemead_valid_tabs() ) )
					$output['current_tab'] = $active_tab;
					
		return apply_filters( 'heatmapthemead_theme_options_validate', $output, $input, $defaults );
	}

endif; // heatmapthemead_theme_options_validate


/* ENQUEUE COLOUR SCHEMES
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_enqueue_color_scheme' ) ):

	function heatmapthemead_enqueue_color_scheme() {
		
		global $heatmapthemead_options_override;
		
		if ( isset ( $heatmapthemead_options_override['color_scheme'] ) ) wp_enqueue_style( $heatmapthemead_options_override['color_scheme'], $heatmapthemead_options_override['color_scheme_path'] . $heatmapthemead_options_override['color_scheme'] . '.css', array(), null );
		else {
			$options = heatmapthemead_get_theme_options();
			$color_scheme = $options['color_scheme'];
		
			if ( 'darthed' == $color_scheme )
				wp_enqueue_style( 'darthed', get_template_directory_uri() . '/colours/darthed.css', array(), null );
			do_action( 'heatmapthemead_enqueue_color_scheme', $color_scheme );
		}
	}

endif; // heatmapthemead_enqueue_color_scheme

add_action( 'wp_enqueue_scripts', 'heatmapthemead_enqueue_color_scheme', 9999 );


/* ADD STYLE BLOCK FOR CURRENT LINK COLOUR
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_print_link_color_style' ) ):

	function heatmapthemead_print_link_color_style() {
		$options = heatmapthemead_get_theme_options();
		$link_color = $options['link_color'];
	
		$default_options = heatmapthemead_get_default_theme_options();
	?>
		<style>
			/* Link color */
			a {
				color: <?php echo heatmapthemead_sanitize_hex_color ( $link_color ); ?>;
			}
		</style>
	<?php
	}

endif; // heatmapthemead_print_link_color_style

add_action( 'wp_head', 'heatmapthemead_print_link_color_style' );


/* ADD STYLE BLOCK FOR MAXIMUM THEME WIDTH
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_print_max_width' ) ):

	function heatmapthemead_print_max_width() {
		
		$options = heatmapthemead_get_theme_options();
		
		global $heatmapthemead_options_override;
		
		if ( isset ( $heatmapthemead_options_override['max_width'] ) ) $max_width = $heatmapthemead_options_override['max_width'];
		else {
			$max_width = $options['max_width'];
		}
	?>
		<style>
			/* Max Width */
			#heatmapthemead-leaderboard,
			nav.main-navigation,
			nav.secondary-navigation,
			#heatmapthemead-branding-container,
			.heatmapthemead-layout-both-sidebars #heatmapthemead-main,
			.heatmapthemead-layout-primary-sidebar-content #heatmapthemead-main,
			.heatmapthemead-layout-content-secondary-sidebar #heatmapthemead-main,
			.heatmapthemead-layout-content #heatmapthemead-main
			{
				max-width: <?php echo absint ( $max_width ); ?>px;
			}
		</style>
		
	<?php
		if ( isset ($options['full_width_navigation'])) {
			if ($options['full_width_navigation'] == 'off') {
			?>
			<style>
				#heatmapthemead-header, #heatmapthemead-footer { 
					max-width: <?php echo absint ( $max_width ); ?>px; 
				} 
			</style>
			<?php
			}
		}
	?>
		
	<?php
	}

endif; // heatmapthemead_print_max_width

add_action( 'wp_head', 'heatmapthemead_print_max_width' );


/* ADD STYLE BLOCK FOR FONT STYLES
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_print_font_css' ) ):

	function heatmapthemead_print_font_css() {
	
		$options = heatmapthemead_get_theme_options();
		
		if (isset($options ['font_style'])) {
	
			$current_combo = $options ['font_style'];
			
			switch ($current_combo) {
			case "arial": 
			?>
				<style>
					/* Font Style */
					h1,h2,h3,h4,h5,h6,
					#heatmapthemead-header-text p#site-title,
					#heatmapthemead-header-text p#site-description { font-family: Arial, Helvetica, sans-serif; }
					.heatmapthemead-menu { font-family: Arial, Helvetica, sans-serif; }
					body, button, input, select, textarea { font-family:  Arial, Helvetica, sans-serif; }
				</style> 
			<?php
			break;
			
			case "verdana": 
			?>
				<style>
					/* Font Style */
					h1,h2,h3,h4,h5,h6,
					#heatmapthemead-header-text p#site-title,
					#heatmapthemead-header-text p#site-description { font-family: Verdana, Geneva, sans-serif; }
					.heatmapthemead-menu { font-family: Verdana, Geneva, sans-serif; }
					body { font-size: 1.6em; } 
					body, button, input, select, textarea { font-family: Verdana, Geneva, sans-serif; }
				</style> 
			<?php
			break;
						
			case "opensans-arial": 
			?>
				<style>
					/* Font Style */
					h1,h2,h3,h4,h5,h6,
					#heatmapthemead-header-text p#site-title,
					#heatmapthemead-header-text p#site-description { font-family: 'Open Sans', Arial, Helvetica, sans-serif; }
					.heatmapthemead-menu { font-family: 'Open Sans', Arial, Helvetica, sans-serif; }
					body { font-size: 1.7em; }
					body, button, input, select, textarea { font-family:  Arial, Helvetica, sans-serif; }
				</style> 
			<?php
			break;
			}
						
			do_action('heatmapthemead_print_font_css_hook', $current_combo );
			
		}
		else return;
	}

endif; // heatmapthemead_print_font_css

add_action( 'wp_head', 'heatmapthemead_print_font_css' );


/* IMPLEMENT THEME OPTIONS INTO THEME CUSTOMISER
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_customize_register' ) ):

	function heatmapthemead_customize_register( $wp_customize ) {
		$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
		$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
	
		$options  = heatmapthemead_get_theme_options();
		$defaults = heatmapthemead_get_default_theme_options();
	
		$wp_customize->add_setting( 'heatmapthemead_theme_options[color_scheme]', array(
			'default'    => $defaults['color_scheme'],
			'type'       => 'option',
			'capability' => 'edit_theme_options',
		) );
	
		$schemes = heatmapthemead_color_schemes();
		$choices = array();
		foreach ( $schemes as $scheme ) {
			$choices[ $scheme['value'] ] = $scheme['label'];
		}
	
		$wp_customize->add_control( 'heatmapthemead_color_scheme', array(
			'label'    => __( 'Color Scheme', 'heatmapthemead' ),
			'section'  => 'colors',
			'settings' => 'heatmapthemead_theme_options[color_scheme]',
			'type'     => 'radio',
			'choices'  => $choices,
			'priority' => 5,
		) );
	
		// Link Color (added to Color Scheme section in Theme Customizer)
		$wp_customize->add_setting( 'heatmapthemead_theme_options[link_color]', array(
			'default'           => heatmapthemead_get_default_link_color( $options['color_scheme'] ),
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color',
			'capability'        => 'edit_theme_options',
		) );
	
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_color', array(
			'label'    => __( 'Link Color', 'heatmapthemead' ),
			'section'  => 'colors',
			'settings' => 'heatmapthemead_theme_options[link_color]',
		) ) );
	
		// Layout Section
		$wp_customize->add_section( 'heatmapthemead_layout', array(
			'title'    => __( 'Layout', 'heatmapthemead' ),
			'priority' => 50,
		) );
		
		// Default Layout
		$wp_customize->add_setting( 'heatmapthemead_theme_options[theme_layout]', array(
			'type'              => 'option',
			'default'           => $defaults['theme_layout'],
			'sanitize_callback' => 'sanitize_key',
		) );
	
		$layouts = heatmapthemead_layouts( '' );
		$choices = array();
		foreach ( $layouts as $layout ) {
			$choices[$layout['value']] = $layout['label'];
		}
	
		$wp_customize->add_control( 'heatmapthemead_theme_options[theme_layout]', array(
			'label'    => __( 'Default Layout', 'heatmapthemead' ),
			'section'    => 'heatmapthemead_layout',
			'type'       => 'radio',
			'choices'    => $choices,
		) );
	}

endif; // heatmapthemead_customize_register

add_action( 'customize_register', 'heatmapthemead_customize_register', 100 );


/* BIND JS HANDLERS TO MAKE THEME CUSTOMIZER PREVIEW RELOAD CHANGES ASYNCHRONOUSLY
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_customize_preview_js' ) ):

	function heatmapthemead_customize_preview_js() {
		wp_enqueue_script( 'heatmapthemead-customizer', get_template_directory_uri() . '/js/theme-customizer.js', array( 'customize-preview' ), '20120523', true );
	}

endif; // heatmapthemead_customize_preview_js

add_action( 'customize_preview_init', 'heatmapthemead_customize_preview_js' );
?>