<?php
/* 
This file is part of HeatMap Theme AdAptive
See license.txt (distributed with this file) for details of
license, contributors, copyright notices, credits and trademarks.
*/

/* PRE wp_head SETUP
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_head_setup' ) ):
	
	function heatmapthemead_head_setup () {
		
		$options = heatmapthemead_get_theme_options();
		global $page, $paged;
		
		print '<meta charset="'; bloginfo( 'charset' );  print '" />' . HMTA_NL;
		print '<meta name="viewport" content="width=device-width, user-scalable=no, initial-scale=1.0, minimum-scale=1.0, maximum-scale=1.0">' . HMTA_NL;
		
		print '<title>';
		// Print the <title> tag based on what is being viewed.
		wp_title( '|', true, 'right' );
		print '</title>' . HMTA_NL;
		print '<link rel="profile" href="http://gmpg.org/xfn/11" />';
		print '<link rel="pingback" href="'; bloginfo( 'pingback_url' ); print '" />' . HMTA_NL;	
	
		//output links to google fonts if necessary
		heatmapthemead_head_fonts ();
	}

endif; // heatmapthemead_head_setup

/* POST wp_header SETUP
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_post_head_setup' ) ):

	function heatmapthemead_post_head_setup () { 
		if ( function_exists( 'heatmapthemeap_post_head_setup' ) )
			heatmapthemeap_post_head_setup ();
	}

endif; // heatmapthemead_post_head_setup


/* END OF BODY SCRIPTS
----------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_end_body_setup' ) ):
	
	function heatmapthemead_end_body_setup () {
		if ( function_exists( 'heatmapthemeap_end_body_setup' ) )
			heatmapthemeap_end_body_setup ();
	}

endif; // heatmapthemead_end_body_setup


/* FILTER WP_TITLE()
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_wp_title' ) ):

	function heatmapthemead_wp_title( $title, $sep ) {
		global $paged, $page;
	
		if ( is_feed() )
			return $title;
	
		// Add the site name.
		$title .= get_bloginfo( 'name' );
	
		// Add the site description for the home/front page.
		$site_description = get_bloginfo( 'description', 'display' );
		if ( $site_description && ( is_home() || is_front_page() ) )
			$title = "$title $sep $site_description";
	
		// Add a page number if necessary.
		if ( $paged >= 2 || $page >= 2 )
			$title = "$title $sep " . sprintf( __( 'Page %s', 'heatmapthemead' ), max( $paged, $page ) );
	
		return $title;
	}
	
endif; // heatmapthemead_wp_title

add_filter( 'wp_title', 'heatmapthemead_wp_title', 10, 2 ); 


/* INJECT FONT STYLES INTO HEAD
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_head_fonts' ) ):

	function heatmapthemead_head_fonts () {
		
		$options = heatmapthemead_get_theme_options();
		
		if (isset($options ['font_style'])) {
	
			$current_combo = $options ['font_style'];
			
			switch ($current_combo) {
			case "opensans-arial":
				print '<link href="http://fonts.googleapis.com/css?family=Open+Sans" rel="stylesheet" type="text/css">';
				break;
			}
						
			do_action('heatmapthemead_head_fonts_hook', $current_combo );
			
		}
		else return;
	}

endif; // heatmapthemead_head_fonts

/* CLEAR THE CONTENT OF THE CONTENT HOOK
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_clear_the_content_hook' ) ):

	function heatmapthemead_clear_the_content_hook () {
		print '<div class="heatmapthemead-content-clear">&nbsp;</div>';
	}

endif;

/* THE LOOP
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_the_loop' ) ):

	function heatmapthemead_the_loop () {
		
		do_action ( 'heatmapthemead_before_the_loop_hook' );
		
		if ( have_posts() ) :
		
			// Start the Loop
			while ( have_posts() ) : 
			
				the_post(); 
				do_action ( 'heatmapthemead_the_loop_hook' );
		
			endwhile;
		
		elseif ( current_user_can( 'edit_posts' ) ) :
		
			do_action ( 'heatmapthemead_the_post_loop_hook' ); 
		
		endif; 
		
		do_action ( 'heatmapthemead_after_the_loop_hook' );
	}

endif; // heatmapthemead_the_loop


/* THE LOOP ERRORS
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_the_loop_errors' ) ):

	function heatmapthemead_the_loop_errors () { ?>
	
		<article id="post-0" class="post no-results not-found">
			<header class="entry-header">
				<h1 class="entry-title"><?php _e( 'Sorry, there are no posts to display', 'heatmapthemead' ); ?></h1>
			</header> <?php print '<!-- .entry-header --> ' . HMTA_NL; ?>
		
			<div class="entry-content">
				<p><?php printf( __( 'Ready to publish your first post? <a href="%1$s">Get started here</a>.', 'heatmapthemead' ), admin_url( 'post-new.php' ) ); ?></p>
			</div><?php print '<!-- .entry-content --> ' . HMTA_NL; ?>
		</article><?php print '<!-- #post-0 -->'  . HMTA_NL;
	}

endif; // heatmapthemead_the_loop_errors


/* DISPLAY FEATURED PAGE
-------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_featured_page ' ) ):

	function heatmapthemead_featured_page () { 
	
		global $heatmapthemead_options_override;
		$options = heatmapthemead_get_theme_options(); 
		
		if ( ( $options['featured_page'] == 'demo' ) && ( !isset ( $heatmapthemead_options_override['featured_page'] ) ) ) { ?>
			<div id="heatmapthemead-featured-page" class="heatmapthemead-article">
				<div class="entry-content">	
					<?php get_template_part( 'demo' ); ?>
				</div> <!-- .entry-content -->
			</div>  <!-- #heatmapthemead-featured_page --> 
		<?php
		} else {
		?>
			<div id="heatmapthemead-featured-page" class="heatmapthemead-article">
		
				<?php
				
				do_action ( 'heatmapthemead_before_the_featured_page_loop_hook' );
				
				if ( isset ( $heatmapthemead_options_override['featured_page'] ) ) 
					$current_featured_page = $heatmapthemead_options_override['featured_page'];
				else
					$current_featured_page = $options ['featured_page'];
				
				$featured_page_loop = new WP_Query('page_id=' . $current_featured_page . '' ); 
				?>
				
				
				<article id="post-<?php print $current_featured_page; ?>">
					<?php
						
					if ( $featured_page_loop->have_posts() ) :
						while ( $featured_page_loop->have_posts() ) : $featured_page_loop->the_post(); ?>

							<?php
							do_action ( 'heatmapthemead_pre_featured_page_title_hook' );
									 
							if ( $options ['featured_page_title'] == 'on' ) {
								  
							?>
								<header class="entry-header">
									<h1 class="featured-entry-title"><?php the_title(); ?></h1>
								</header> <!-- heatmapthemead-entry-header -->
								
							<?php 
							}	
							
							do_action ( 'heatmapthemead_pre_featured_page_content_hook' );
							
							print '<div class="entry-content">';
								the_content (__('Continue reading...','heatmapthemead'));
							print '<!-- .entry-content -->';
							wp_link_pages( array( 'before' => '<div class="page-links">' . __( 'Pages:', 'heatmapthemead' ), 'after' => '</div>' ) );
							do_action ( 'heatmapthemead_post_featured_page_content_hook' );
		
							edit_post_link( __( 'Edit', 'heatmapthemead' ), '<p class="heatmapthemead-edit-link">', '</p>' );
							print '</div> <!-- entry-content -->';
							print '<div class="heatmapthemead-featured-page-clear">&nbsp;</div>';
							 
						endwhile;
					endif;			
					?>
					
				</article><!-- #post-<?php print $current_featured_page; ?> -->
				<?php wp_reset_query(); 
				
				do_action ( 'heatmapthemead_after_the_featured_page_loop_hook' );
				
				?>
			</div>  <!-- #heatmapthemead-featured_page -->    
		<?php	
		}
	}

endif; // heatmapthemead_featured_page 


/* DISPLAY BLOG POSTS
-------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_blog_posts' ) ):

	function heatmapthemead_blog_posts () { 
	
	global $heatmapthemead_options_override;
	?>	
		<div class="heatmapthemead-article">	
			<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
			
				<?php do_action ( 'heatmapthemead_blog_posts_hook' ); 
					
				edit_post_link( __( 'Edit', 'heatmapthemead' ), '<p class="heatmapthemead-edit-link">', '</p>' ); ?>
			</article><!-- #post-<?php the_ID(); ?> -->
		</div>        
	<?php
		$heatmapthemead_options_override ['blog_posts_displayed'] = true;
	}

endif; // heatmapthemead_blog_posts



/* DISPLAY BLOG POSTS HEADER
-------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_blog_posts_header' ) ):

	function heatmapthemead_blog_posts_header () {
	?>
		<header class="entry-header">
			<h2 class="entry-title h2-simulate-h1"><a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'heatmapthemead' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title(); ?></a></h2>
		</header> <!-- entry-header -->
	<?php
	}

endif; // heatmapthemead_blog_posts_header


/* DISPLAY A SINGLE POST
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_single_post' ) ):

	function heatmapthemead_single_post () { ?>	
	
		<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
		
			<?php do_action ( 'heatmapthemead_single_posts_hook' ); 
				
			edit_post_link( __( 'Edit', 'heatmapthemead' ), '<p class="heatmapthemead-edit-link">', '</p>' ); ?>
		</article><!-- #post-<?php the_ID(); ?> -->        
	<?php	
	}

endif; // heatmapthemead_single_post


/* DISPLAY THE POST HEADER
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_single_post_header' ) ):

	function heatmapthemead_single_post_header () {
	?>
		<header class="entry-header">
			<h1 class="entry-title"><a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'heatmapthemead' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title(); ?></a></h1>
		</header> <!-- heatmapthemead-entry-header -->
	<?php
	}

endif; // heatmapthemead_single_post_header


/* REMOVE MORE LINK SCROLLING
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_remove_more_link_scroll' ) ):

	function heatmapthemead_remove_more_link_scroll( $link ) {
		
		$link = preg_replace( '|#more-[0-9]+|', '', $link );
		return $link;
	}
	
	endif; // heatmapthemead_remove_more_link_scroll

add_filter( 'the_content_more_link', 'heatmapthemead_remove_more_link_scroll' ); 



/* CHANGE THE MORE LINK FOR EXCERPTS
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_new_excerpt_more' ) ):

	function heatmapthemead_new_excerpt_more($output) {
		
		return $output . '<br/><a href="'. get_permalink() . '" class="more-link" >' . __('Continue reading...','heatmapthemead') . '</a>';
	}
	add_filter('get_the_excerpt', 'heatmapthemead_new_excerpt_more');
	
	endif; // heatmapthemead_new_excerpt_more


/* DISPLAY THE CONTENT
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_the_content' ) ):

	function heatmapthemead_the_content () {
	
		global $post;
		
		if ( ( is_home () ) || ( is_front_page () ) ) {
			
			if(!empty($post->post_excerpt)) {
				//This post has an excerpt, so let's display it
					print '<div class="entry-content">';
						the_excerpt();
					print '</div> <!-- .entry-content -->';
				} else {
					// This post has no excerpt
					print '<div class="entry-content">';
						the_content (__('Continue reading...','heatmapthemead'));
					print '</div> <!-- .entry-content -->';
					wp_link_pages( array( 'before' => '<div class="page-links">' . __( 'Pages:', 'heatmapthemead' ), 'after' => '</div>' ) );
				}			
			}
		else {	
			// this is a post that is not on the home page or front page so just show the content
			print '<div class="entry-content">'; 
				the_content ('Continue reading...');
			print '</div> <!-- .entry-content -->';	
			wp_link_pages( array( 'before' => '<div class="page-links">' . __( 'Pages:', 'heatmapthemead' ), 'after' => '</div>' ) );
		}
	}

endif; // heatmapthemead_the_content


/* DISPLAY AN EXCERPT
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_the_excerpt' ) ):

	function heatmapthemead_the_excerpt () { ?>
	
		<div class="entry-content">
			<?php the_excerpt( __( 'Continue reading', 'heatmapthemead' ) ); ?>
		</div><!-- .entry-content -->
		<?php wp_link_pages( array( 'before' => '<div class="page-links">' . __( 'Pages:', 'heatmapthemead' ), 'after' => '</div>' ) ); ?>
	<?php
	}

endif; // heatmapthemead_the_excerpt


/* FEATURED IMAGE
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_featured_image' ) ):

	function heatmapthemead_featured_image () { 
	
		if ( has_post_thumbnail() ) { ?>	
			
			<div class="heatmapthemead-featured-image">
			<?php
			
				print '<a href="' . get_permalink() . '">';
					the_post_thumbnail('large');
				print '</a>';
			?>
			</div><!-- .heatmapthemead-featured-image -->
	<?php
		}
	}

endif; // heatmapthemead_featured_image

/* COMMENT AND PINGBACKS
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_comment' ) ) :

	function heatmapthemead_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
		switch ( $comment->comment_type ) :
			case 'pingback' :
			case 'trackback' :
		?>
		<li class="post pingback">
			<div class="heatmapthemead-comment-pingback">
				<p><?php _e( 'Pingback:', 'heatmapthemead' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'heatmapthemead' ), '<span class="edit-link">', '</span>' ); ?></p>
			</div> <!-- heatmapthemead-comment-pingback -->
		<?php
				break;
			default :
		?>
		<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
			<div class="heatmapthemead-comment-article">
				<article id="comment-<?php comment_ID(); ?>" class="comment">
					<footer class="comment-meta">
						<div class="reply">
							<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'heatmapthemead' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
						</div><!-- .reply -->
						<div class="comment-author vcard">
							<?php
								$avatar_size = 68;
								if ( '0' != $comment->comment_parent )
									$avatar_size = 39;
								echo get_avatar( $comment, $avatar_size );
		
								/* translators: 1: comment author, 2: date and time */
								printf( __( '%1$s on %2$s <span class="says">said:</span>', 'heatmapthemead' ),
									sprintf( '<span class="fn">%s</span>', get_comment_author_link() ),
									sprintf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
										esc_url( get_comment_link( $comment->comment_ID ) ),
										get_comment_time( 'c' ),
										/* translators: 1: date, 2: time */
										sprintf( __( '%1$s at %2$s', 'heatmapthemead' ), get_comment_date(), get_comment_time() )
									)
								);
	
							?>
		
							<?php edit_comment_link( __( 'Edit', 'heatmapthemead' ), '<span class="edit-link">', '</span>' ); ?>
						</div><!-- .comment-author .vcard -->
		
						<?php if ( $comment->comment_approved == '0' ) : ?>
							<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'heatmapthemead' ); ?></em>
							<br />
						<?php endif; ?>
		
					</footer>
		
					<div class="comment-content"><?php comment_text(); ?></div>
				</article><!-- #comment-## -->
			</div><!-- .heatmapthemead-comment-article -->
	
		<?php
				break;
		endswitch;
	}
	
endif; // ends check for heatmapthemead_comment()


/* DISPLAY 'POSTED ON' DETAILS + COMMENTS LINK
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_posted_on' ) ) :

 	// Prints HTML with meta information for the current post-date/time and author.
	
	function heatmapthemead_posted_on() {
			
			$options = heatmapthemead_get_theme_options();
			
			print '<div class="heatmapthemead-header-entry-meta entry-meta">';
				
				if (( $options['meta_date'] == 'on' ) || ( $options['meta_author'] == 'on' )) {
					print '<span class="heatmapthemead-post-details">';
					_e ('Posted','heatmapthemead');
				}
				
				if ( $options['meta_date'] == 'on' ) {
					print ' ';
					_e ('on','heatmapthemead');
					print ' ';
					print '<a href="'. esc_url( get_permalink() ) . '" title="' . esc_attr( get_the_time() ) . '" rel="bookmark">';
					print '<time class="entry-date" datetime="' . esc_attr( get_the_date( 'c' ) ) . '">' . esc_html( get_the_date() ) . '</time>';
					print '</a>';
				}
				
				if ( $options['meta_author'] == 'on' ) {
					print '<span class="byline">';
					print ' ';
					_e ('by','heatmapthemead');
					print ' ';
					print '<span class="author vcard">';
					print '<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '" title="' . esc_attr( sprintf( __( 'View all posts by %s', 'heatmapthemead' ), get_the_author() ) ) . '" rel="author">' . esc_html( get_the_author() ) . '</a>';
					print '</span>';
					print '</span>';
				}
				
				if (( $options['meta_date'] == 'on' ) || ( $options['meta_author'] == 'on' )) print '</span>';
			
				if ( $options['meta_comments'] == 'on' ) {	
					if ( comments_open() || ( '0' != get_comments_number() && ! comments_open() ) ) : ?>
					<span class="comments-link"><?php comments_popup_link( __( 'Leave a comment', 'heatmapthemead' ), __( '1 Comment', 'heatmapthemead' ), __( '% Comments', 'heatmapthemead' ) ); ?></span>
					<?php 
					endif; 
				}
				?>
			</div><!-- .heatmapthemead-entry-meta -->
			<?php
	}
endif;


/* DISPLAY CONTENT NAV (next post / previous post etc)
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_content_nav' ) ):

	// Display navigation to next/previous pages when applicable

	function heatmapthemead_content_nav () {
		global $wp_query;
	
		$nav_class = 'site-navigation paging-navigation';
		if ( is_single() )
			$nav_class = 'site-navigation post-navigation';
	
		?>
		<div id="heatmapthemead-post-navigation">
            <nav role="navigation" id="nav-below" class="<?php echo $nav_class; ?>">
        
            <?php if ( is_single() ) : // navigation links for single posts ?>
        
                <?php previous_post_link( '<div class="nav-previous">%link</div>', '<span class="meta-nav">' . _x( '&laquo;', 'Previous post link', 'heatmapthemead' ) . '</span> %title' ); ?>
                <?php next_post_link( '<div class="nav-next">%link</div>', '%title <span class="meta-nav">' . _x( '&raquo;', 'Next post link', 'heatmapthemead' ) . '</span>' ); ?>
        
            <?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : // navigation links for home, archive, and search pages ?>
        
                <?php if ( get_next_posts_link() ) : ?>
                <div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&laquo;</span> Older posts', 'heatmapthemead' ) ); ?></div>
                <?php endif; ?>
        
                <?php if ( get_previous_posts_link() ) : ?>
                <div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&raquo;</span>', 'heatmapthemead' ) ); ?></div>
                <?php endif; ?>
        
            <?php endif; ?>
        
            </nav><!-- .<?php echo $nav_class; ?> -->
        </div><!-- #heatmapthemead-post-navigation -->
		<?php
	}

endif; // heatmapthemead_content_nav


/* ARTICLE META (categories and tags)
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_article_meta' ) ):
	
	// Display categories and tags if required

	function heatmapthemead_article_meta () { ?>
    
    	<?php 
		global $wp_query; 
		$options = heatmapthemead_get_theme_options();
		
		
		if ( ( $options['meta_categories'] == 'on' ) || ( $options['meta_tags'] == 'on' ) ) :
			?>
			<div class="heatmapthemead-footer-entry-meta">
				<footer class="entry-meta">
				
					<?php 
					if ( 'post' == get_post_type() ) : // Hide category and tag text for pages on Search 
					?>
					
						<?php
						if ( $options['meta_categories'] == 'on' ) :
						
							/* translators: used between list items, there is a space after the comma */
							$categories_list = get_the_category_list( __( ', ', 'heatmapthemead' ) );
							
							if ( $categories_list && heatmapthemead_categorized_blog() ) :
							?>
								<p class="heatmapthemead-cat-links">
									<?php printf( __( 'Categories: %1$s', 'heatmapthemead' ), $categories_list ); ?>
								</p>
							<?php 
							endif; // End if categories 
						endif;
						?>
						
						<?php
						if ( $options['meta_tags'] == 'on' ) :
							
							/* translators: used between list items, there is a space after the comma */
							$tags_list = get_the_tag_list( '', __( ', ', 'heatmapthemead' ) );
							if ( $tags_list ) :
							?>
							<p class="heatmapthemead-tag-links">
								<?php printf( __( 'Tags: %1$s', 'heatmapthemead' ), $tags_list ); ?>
							</p>
							<?php 
							endif; // End if $tags_list ?>	
					<?php 
						endif;
					endif; // End if 'post' == get_post_type() 
					?>
			
				</footer><!-- #heatmapthemead-article-meta -->    
			</div><!-- #footer-entry-meta --> 
    <?php 
		endif;
    }
	
endif; // heatmapthemead_article_meta


/* CATEGORIZED BLOG 
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_categorized_blog' ) ):

function heatmapthemead_categorized_blog() {

	// Create an array of all the categories that are attached to posts
	$all_the_cool_cats = get_categories( array(
		'hide_empty' => 1,
	) );

	// Count the number of categories that are attached to the posts
	$all_the_cool_cats = count( $all_the_cool_cats );

	if ( '1' != $all_the_cool_cats ) {
		// This blog has more than 1 category so heatmapthemead_categorized_blog should return true
		return true;
	} else {
		// This blog has only 1 category so heatmapthemead_categorized_blog should return false
		return false;
	}
}

endif; // heatmapthemead_categorized_blog


// LIKE BUTTONS
/*-----------------------------------------------------------------------------------*/

// only calls the like buttons if the pro plugin is installed

if ( ! function_exists( 'heatmapthemead_like_buttons' ) ):

	function heatmapthemead_like_buttons() {
		
		if ( function_exists( 'heatmapthemeap_like_buttons' ) )
			heatmapthemeap_like_buttons();
	}

endif; // heatmapthemead_like_buttons


/* CHECK IF THERE ARE COMMENTS
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_comments' ) ):

	function heatmapthemead_comments () { 
		// If comments are open or we have at least one comment, load up the comment template
		if ( comments_open() || '0' != get_comments_number() )
			comments_template( '', true );	
	}
	
endif; // heatmapthemead_comments


/* COMMENTS AND PINGBACKS
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_comment' ) ) :
 
// Template for comments and pingbacks
 
function heatmapthemead_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'heatmapthemead' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(Edit)', 'heatmapthemead' ), ' ' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<footer>
				<div class="comment-author heatmapthemead-vcard">
					<?php echo get_avatar( $comment, 40 ); ?>
					<?php printf( __( '%s <span class="says">says:</span>', 'heatmapthemead' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
				</div><!-- .comment-author .vcard -->
				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em><?php _e( 'Your comment is awaiting moderation.', 'heatmapthemead' ); ?></em>
					<br />
				<?php endif; ?>
				<div class="comment-meta commentmetadata">
					<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>"><time datetime="<?php comment_time( 'c' ); ?>">
					<?php
						/* translators: 1: date, 2: time */
						printf( __( '%1$s at %2$s', 'heatmapthemead' ), get_comment_date(), get_comment_time() ); ?>
					</time></a>
					<?php edit_comment_link( __( '(Edit)', 'heatmapthemead' ), ' ' );
					?>
				</div><!-- .comment-meta .commentmetadata -->
			</footer>

			<div class="comment-content"><?php comment_text(); ?></div>

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</article><!-- #comment-## -->
<?php
			break;
	endswitch;
}
endif; // ends check for heatmapthemead_comment()


/*  ARCHIVE POSTS HEADER
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_archive_posts_header' ) ):

	function heatmapthemead_archive_posts_header () {
		
		do_action('heatmapthemead_pre_archive_header_hook');
	?>  
		<header class="page-header">
		
			<?php do_action('heatmapthemead_pre_archive_title_hook'); ?>
		
			<h1 class="entry-title">
			
				<?php
					if ( is_category() ) {
						printf( __( '%s', 'heatmapthemead' ), '<span>' . single_cat_title( '', false ) . '</span>' );
	
					} elseif ( is_tag() ) {
						printf( __( 'Posts tagged with \'%s\'', 'heatmapthemead' ), '<span>' . single_tag_title( '', false ) . '</span>' );
	
					} elseif ( is_author() ) {
						// Queue the first post, that way we know what author we're dealing with (if that is the case).
						the_post();
						printf( __( 'Posts by %s', 'heatmapthemead' ), '<span class="vcard"><a class="url fn n" href="' . get_author_posts_url( get_the_author_meta( "ID" ) ) . '" title="' . esc_attr( get_the_author() ) . '" rel="me">' . get_the_author() . '</a></span>' );
						// Since we called the_post() above, 
						// we need to rewind the loop back to the beginning that way we can run the loop properly, in full.
						rewind_posts();
	
					} elseif ( is_day() ) {
						printf( __( 'Daily Archives: %s', 'heatmapthemead' ), '<span>' . get_the_date() . '</span>' );
	
					} elseif ( is_month() ) {
						printf( __( 'Monthly Archives: %s', 'heatmapthemead' ), '<span>' . get_the_date( 'F Y' ) . '</span>' );
	
					} elseif ( is_year() ) {
						printf( __( 'Yearly Archives: %s', 'heatmapthemead' ), '<span>' . get_the_date( 'Y' ) . '</span>' );
	
					} else {
						_e( 'Archives', 'heatmapthemead' );
	
					}
					
				?>
			</h1>
			
			<?php do_action('heatmapthemead_after_archive_title_hook'); ?>

			<?php
			do_action('heatmapthemead_pre_archive_description_hook');
		
			if ( is_category() ) {
				// show an optional category description
				$category_description = category_description();
				if ( ! empty( $category_description ) )
					echo apply_filters( 'category_archive_meta', '<div class="taxonomy-description">' . $category_description . '</div>' );
	
			} elseif ( is_tag() ) {
				// show an optional tag description
				$tag_description = tag_description();
				if ( ! empty( $tag_description ) )
					echo apply_filters( 'tag_archive_meta', '<div class="taxonomy-description">' . $tag_description . '</div>' );
			}
			
			print '<div class="heatmapthemead-archive-description-clear">&nbsp;</div>';
			do_action('heatmapthemead_after_archive_description_hook');
			?>
			
		</header>	
	
		<?php rewind_posts(); ?>
		  
	<?php
	}

endif; // heatmapthemead_archive_posts_header


/*  SEARCH HEADER
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_search_results_header' ) ):

	function heatmapthemead_search_results_header () {
	?>  
		<header class="page-header">
			<h2 class="page-title h2-simulate-h1"><?php printf( __( 'Search Results for: %s', 'heatmapthemead' ), '<span>' . get_search_query() . '</span>' ); ?></h2>
		</header>
	<?php
	}

endif; // heatmapthemead_search_results_header


/* NO SEARCH RESULTS
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_no_search_results' ) ):

	function heatmapthemead_no_search_results () { ?>
	
		<article id="post-0" class="post no-results not-found">
			<header class="entry-header">
				<h2 class="entry-title h2-simulated-h1">No search results found</h2>
			</header> <?php print '<!-- .entry-header --> ' . HMTA_NL; ?>
	 
			<?php heatmapthemead_help_me_im_lost (); ?>
		
		</article><?php print '<!-- #post-0 -->' . HMTA_NL;
	}

endif; // heatmapthemead_no_search_results


/* 404 ERRORS
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_404' ) ):

	function heatmapthemead_404 () { ?>
	
		<article id="post-0" class="post error404 not-found">
			<header class="entry-header">
				<h1 class="entry-title"><?php _e( 'Sorry, that page cannot be found.', 'heatmapthemead' ); ?></h1>
			</header>
			
			<?php heatmapthemead_help_me_im_lost (); ?>
			
		</article><!-- #post-0 -->
	<?php
	}

endif; //heatmapthemead_404


/* HELP ME I'M LOST
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_help_me_im_lost' ) ):

	function heatmapthemead_help_me_im_lost () { ?>
	
		<div class="entry-content">
			<p><?php _e( 'Maybe try one of the links below or a search?', 'heatmapthemead' ); ?></p>
	
			<?php get_search_form(); ?>
	
			<?php the_widget( 'WP_Widget_Recent_Posts' ); ?>
	
			<div class="widget">
				<h2 class="widgettitle"><?php _e( 'Most Used Categories', 'heatmapthemead' ); ?></h2>
				<ul>
				<?php wp_list_categories( array( 'orderby' => 'count', 'order' => 'DESC', 'show_count' => 1, 'title_li' => '', 'number' => 10 ) ); ?>
				</ul>
			</div>
	
			<?php
			/* translators: %1$s: smilie */
			$archive_content = '<p>' . sprintf( __( 'Try looking in the monthly archives. %1$s', 'heatmapthemead' ), convert_smilies( ':)' ) ) . '</p>';
			the_widget( 'WP_Widget_Archives', 'dropdown=1', "after_title=</h2>$archive_content" );
			?>
	
			<?php the_widget( 'WP_Widget_Tag_Cloud' ); ?>
	
		</div><!-- .entry-content -->
	<?php
	}

endif; // heatmapthemead_help_me_im_lost



/* SITEMAP
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'heatmapthemead_sitemap' ) ):

	function heatmapthemead_sitemap () { ?>
	
		<article id="post-0" class="post sitemap">
			<header class="entry-header">
				<h1 class="entry-title"><?php _e( 'Sitemap', 'heatmapthemead' ); ?></h1>
			</header>
			
			<div class="entry-content">
		
				<h2 id="heatmapthemead_sitemap_pages">Pages</h2>
				<ul>
					<?php wp_list_pages( 'title_li=' ); ?>
				</ul>
				
				<h2 id="heatmapthemead_sitemap_posts">Posts</h2>
				<?php
				$sitemap_cats = get_categories();
				
				foreach ($sitemap_cats as $sitemap_cat) {
					
					print "<h3 class='heatmapthemead_sitemap_catpost'>" . $sitemap_cat->cat_name . '</h3>';
					print '<ul>';
					
					query_posts('posts_per_page=-1&cat=' . $sitemap_cat->cat_ID );
					
				  	while( have_posts() ) {
						the_post();
						
						$sitemap_category = get_the_category();
						
						if ($sitemap_category[0]->cat_ID == $sitemap_cat->cat_ID):
					  		print '<li><a href="' .get_permalink(). '">' . get_the_title() . '</a></li>';
						endif;
					}
					
				 	print '</ul>';
				}
				?>
		
			</div><!-- .entry-content -->
		
		</article><!-- #post-0 -->
	<?php
	}

endif; // sitemap



/* DISPLAY SOCIAL ICONS
--------------------------------------------------------------------------------------------- */

if (!function_exists('heatmapthemead_display_social_icons')):

	function heatmapthemead_display_social_icons () {        
	
		$options = heatmapthemead_get_theme_options();
		
		print '<div class="heatmapthemead-social-icons">';
		
		if ($options['facebook_url']) {
			print '<a id="heatmapthemead-fb-social-icon" class="heatmapthemead-social-icon" href="';
			print esc_url ( $options['facebook_url'] );
			print '" target="_blank"><img src="';
			print get_stylesheet_directory_uri();
			print '/images/facebook.png" alt="" /></a>';
		} 
		
		if ($options['twitter_url']) {
			print '<a id="heatmapthemead-twitter-social-icon" class="heatmapthemead-social-icon"  href="';
			print esc_url ( $options['twitter_url'] );
			print '" target="_blank"><img src="';
			print get_stylesheet_directory_uri();
			print '/images/twitter.png" alt="" /></a>';
		} 
		
		if ($options['googleplus_url']) {
			print '<a id="heatmapthemead-googleplus-social-icon" class="heatmapthemead-social-icon"  href="';
			print esc_url ( $options['googleplus_url'] );
			print '" target="_blank"><img src="';
			print get_stylesheet_directory_uri();
			print '/images/googleplus.png" alt="" /></a>';
		} 
		
		if ($options['youtube_url']) {
			print '<a id="heatmapthemead-youtube-social-icon" class="heatmapthemead-social-icon"  href="';
			print esc_url ( $options['youtube_url'] );
			print '" target="_blank"><img src="';
			print get_stylesheet_directory_uri();
			print '/images/youtube.png" alt="" /></a>';
		}
		
		if ($options['linkedin_url']) {
			print '<a id="heatmapthemead-linkedin-social-icon" class="heatmapthemead-social-icon"  href="';
			print esc_url ( $options['linkedin_url'] );
			print '" target="_blank"><img src="';
			print get_stylesheet_directory_uri();
			print '/images/linkedin.png" alt="" /></a>';
		}
		
		if ($options['myspace_url']) {
			print '<a id="heatmapthemead-myspace-social-icon" class="heatmapthemead-social-icon"   href="';
			print esc_url ( $options['myspace_url'] );
			print '" target="_blank"><img src="';
			print get_stylesheet_directory_uri();
			print '/images/myspace.png" alt="" /></a>';
		}
		
		if ($options['rss_icon'] == 'on') {
			if ($options['rss_url']) {
				print '<a id="heatmapthemead-rss-social-icon" class="heatmapthemead-social-icon" href="';
				print esc_url ( $options['rss_url'] );
				print '" target="_blank"><img src="';
				print get_stylesheet_directory_uri();
				print '/images/rss-feed.png" alt="" /></a>';
			}
			else
			{
				print '<a id="heatmapthemead-rss-social-icon" class="heatmapthemead-social-icon" href="';
				print bloginfo('rss2_url');
				print'"><img src="';
				print get_stylesheet_directory_uri();
				print '/images/rss-feed.png" alt="" /></a>';
			}		
		}
		
		if ($options['rss_comments_icon']  == 'on') {
			if ($options['rss_comments_url']) {
				print '<a id="heatmapthemead-rss-comments-social-icon" class="heatmapthemead-social-icon" href="';
				print esc_url ( $options['rss_comments_url'] );
				print '" target="_blank"><img src="';
				print get_stylesheet_directory_uri();
				print '/images/rss-comments.png" alt="" /></a>';
			}
			else
			{
				print '<a id="heatmapthemead-rss-comments-social-icon" class="heatmapthemead-social-icon" href="';
				bloginfo('comments_rss2_url');
				print'"><img src="';
				print get_stylesheet_directory_uri();
				print '/images/rss-comments.png"  alt="" /></a>';
			}		
		}
		
		
		print '</div> <!--.heatmapthemead-social-icons -->';
	
	}
	
endif; // heatmapthemead_display_social_icons

// FILTER BODY CLASS TO ADD HEATMAP RESPONSIVE CLASSES
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'heatmapthemead_body_class' ) ):

	function heatmapthemead_body_class ( $classes, $class ) {
		
		// Get the globals for theme layout and max width so we can override the options if needed
		global $heatmapthemead_options_override;
		
		$options = heatmapthemead_get_theme_options();
		
		// if click missile is installed and it detects a mobile device then set a class
		
		if ( function_exists ( 'cmam_is_mobile' ) ) {
			if ( cmam_is_mobile() == true )  { 
				$classes[] = 'heatmapthemead-reading-on-a-mobile';
			}
		}
		
		// okay if the theme layout global is set then override the options theme layout
		if ( isset ( $heatmapthemead_options_override['theme_layout'] ) ) $classes[] = 'heatmapthemead-layout-' . $heatmapthemead_options_override['theme_layout'];
		else {
			// use the options theme layout based on what kind of page is showing
			$temp_layout_class = '';
			// set the default one
			$temp_layout_class = 'heatmapthemead-layout-' . $options['theme_layout'];
			// and then change it if anything has been added to filter it (ie add more layout options)
			$temp_layout_class = apply_filters('heatmapthemead_add_layout_class', $temp_layout_class );
			$classes[] = $temp_layout_class;
			
		}
		
		// if the global max width is set then use that to set the theme width
		if ( isset ( $heatmapthemead_options_override['max_width'] ) ) $classes[] = 'heatmapthemead-layout-' . $heatmapthemead_options_override['max_width'];
		else {
			// otherwise use the max width from the theme options
			if ( $options['max_width'] ) $classes[] = ' heatmapthemead-max-width-' . $options['max_width'];
		}
		
		if ( heatmapthemead_is_sidebar_active ('heatmapthemeadheader') ) 
			$classes[] = ' heatmapthemeadheader-active';
			
		// if there is no 'posted by' information under the post title heading then set a class so we can make so extra space under it
		// otherwise the heading gets too close to the content of the page / post	
		if 	( ( is_page () && $options['page_meta'] == 'off') || 
			( is_page () && $heatmapthemead_options_override['page_meta'] == 'off' ) ||
			( (is_single () || is_home () || is_front_page () || is_archive () ) && ( $options['meta_date'] == 'off' ) && ( $options['meta_author'] == 'off' ) && ( $options['meta_comments'] == 'off' ) ) )
			$classes[] = ' heatmapthemead-posted-by-off'; 
		
		return $classes;
	}	

endif; // heatmapthemead_body_class

add_filter('body_class','heatmapthemead_body_class',10,2);
?>